#!/bin/bash

sha=$(cat version.txt)

property=$1

if [ "$property" == "-v" ]; then
  echo "jdart-sv-comp20-$sha"
  exit
fi

path=`pwd`

shift
classpath=""

for folder in $@; do
mainclass=""
taskdef=""
classpath="$classpath:$path/$folder"
if [[ -n $(find $folder |grep Main.java) ]]; then
  mainclass=$(find $folder |grep Main.java)
fi
done
if [[ -z $mainclass ]]; then
  echo "Could not find main class to execute program"
  echo "== DONT-KNOW"
  exit 1
fi
echo "computed classpath: $classpath"
echo "found main class: $mainclass"

rm _jdart.jpf
rm _jdart.err
rm _jdart.log

echo "
@include=basic.jpf

###############################################################################
#
# default jdart tools
#
shell=gov.nasa.jpf.jdart.JDart

symbolic.dp=bounded
bounded.dp=z3
symbolic.dp.z3.bitvectors=true
bounded.iter=7
bounded.type=fibonacci

###############################################################################
#
# logging and jpf output
#
# log.finest=jdart
log.info=constraints,jdart

# suppress jpf output
report.console.start=
report.console.finished=
report.console.property_violation=

jdart.configs.all_fields_symbolic.symbolic.include=this.*
listener=gov.nasa.jpf.jdart.svcomp.SVCompAssumeListener,gov.nasa.jpf.jdart.analysis.AnalysisBorderListener
###

target=Main
concolic.method.main=Main.main(args:[Ljava/lang/String;)
concolic.method=main

jpf-jdart.classpath=$classpath" > _jdart.jpf

jdk8u222-b10/bin/javac -cp $classpath $path/$mainclass

./jdart.sh _jdart.jpf > _jdart.log 2> _jdart.err

#Eventually, we print non readable character from the SMT solver to the log.
sed 's/[^[:print:]]//' _jdart.log > _jdart.processed
mv _jdart.processed _jdart.log

errors=`cat _jdart.log | grep ERROR | grep java.lang.AssertionError | cut -d ':' -f 2`
err=0
if [ ! -z "$errors" ]; then
  echo "Errors:"
  echo "$errors"
  err=`echo $errors| wc -l`
fi

completed=`cat _jdart.err | grep "Completed"`
if [ -z "$completed" ]; then

  echo "== TIMEOUT";
  exit 1;
fi

cat _jdart.log | grep "#"

dk=`cat _jdart.log | grep "# DONT" | cut -d ':' -f 2 | xargs`


if [ "$err" -eq "0" ]; then
  if [ "$dk" -eq "0" ]; then
      echo "== OK"
  else
    echo "== DONT-KNOW"
  fi
else
  if [ "$dk" -eq "0" ]; then
      echo "== ERROR"
  else
     echo "== DONT-KNOW"
  fi
fi

